@@ -25,9 +25,9 @@
     for (var i = 0; i < links.length; i++) {
       if (links[i].getAttribute("href") === "#")
         continue;
-      var path = paths(links[i].pathname);
+      var nav_path = paths(links[i].pathname);
 
-      var length = prefix_length(cur_path, path);
+      var length = prefix_length(nav_path, cur_path);
       if (length > max_length) {
         max_length = length;
         pos = i;
@@ -78,9 +78,9 @@
     element.setAttribute('data-original-title', tooltipOriginalTitle);
   }
 
-  if(Clipboard.isSupported()) {
+  if(ClipboardJS.isSupported()) {
     $(document).ready(function() {
-      var copyButton = "<button type='button' class='btn btn-primary btn-copy-ex' type = 'submit' title='Copy to clipboard' aria-hidden='true' data-toggle='tooltip' data-placement='left auto' data-trigger='hover' data-clipboard-copy><i class='fa fa-copy' aria-hidden='true'></i></button>";
+      var copyButton = "<button type='button' class='btn btn-primary btn-copy-ex' type = 'submit' title='Copy to clipboard' aria-label='Copy to clipboard' data-toggle='tooltip' data-placement='left auto' data-trigger='hover' data-clipboard-copy><i class='fa fa-copy'></i></button>";
 
       $(".examples, div.sourceCode").addClass("hasCopyButton");
 
@@ -91,7 +91,7 @@
       $('.btn-copy-ex').tooltip({container: 'body'});
 
       // Initialize clipboard:
-      var clipboardBtnCopies = new Clipboard('[data-clipboard-copy]', {
+      var clipboardBtnCopies = new ClipboardJS('[data-clipboard-copy]', {
         text: function(trigger) {
           return trigger.parentNode.textContent;
         }
